# CHANGELOG

<!-- version list -->

## v0.1.0-alpha.1 (2025-07-25)

### Features

- Add support for disabling telemetry ([#7](https://github.com/aptible/unpage/pull/7),
  [`037798c`](https://github.com/aptible/unpage/commit/037798cbaec8ded81b316762421f00ba3c2b1bae))


## v0.0.1-alpha.1 (2025-07-25)

- Initial Release
